==> aws-java-sdk-gamelift-1.11.59-sources.jar: com/amazonaws/services/gamelift/model/transform/DescribePlayerSessionsRequestMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.gamelift.model.transform;

import java.io.ByteArrayInputStream;
import java.util.Collections;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.SdkClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.gamelift.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * DescribePlayerSessionsRequest Marshaller
 */
public class DescribePlayerSessionsRequestMarshaller implements Marshaller<Request<DescribePlayerSessionsRequest>, DescribePlayerSessionsRequest> {

    private final SdkJsonProtocolFactory protocolFactory;

    public DescribePlayerSessionsRequestMarshaller(SdkJsonProtocolFactory protocolFactory) {
        this.protocolFactory = protocolFactory;
    }

    public Request<DescribePlayerSessionsRequest> marshall(DescribePlayerSessionsRequest describePlayerSessionsRequest) {

        if (describePlayerSessionsRequest == null) {
            throw new SdkClientException("Invalid argument passed to marshall(...)");
        }

        Request<DescribePlayerSessionsRequest> request = new DefaultRequest<DescribePlayerSessionsRequest>(describePlayerSessionsRequest, "AmazonGameLift");
        request.addHeader("X-Amz-Target", "GameLift.DescribePlayerSessions");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final StructuredJsonGenerator jsonGenerator = protocolFactory.createGenerator();

            jsonGenerator.writeStartObject();

            if (describePlayerSessionsRequest.getGameSessionId() != null) {
                jsonGenerator.writeFieldName("GameSessionId").writeValue(describePlayerSessionsRequest.getGameSessionId());
            }
            if (describePlayerSessionsRequest.getPlayerId() != null) {
                jsonGenerator.writeFieldName("PlayerId").writeValue(describePlayerSessionsRequest.getPlayerId());
            }
            if (describePlayerSessionsRequest.getPlayerSessionId() != null) {
                jsonGenerator.writeFieldName("PlayerSessionId").writeValue(describePlayerSessionsRequest.getPlayerSessionId());
            }
            if (describePlayerSessionsRequest.getPlayerSessionStatusFilter() != null) {
                jsonGenerator.writeFieldName("PlayerSessionStatusFilter").writeValue(describePlayerSessionsRequest.getPlayerSessionStatusFilter());
            }
            if (describePlayerSessionsRequest.getLimit() != null) {
                jsonGenerator.writeFieldName("Limit").writeValue(describePlayerSessionsRequest.getLimit());
            }
            if (describePlayerSessionsRequest.getNextToken() != null) {
                jsonGenerator.writeFieldName("NextToken").writeValue(describePlayerSessionsRequest.getNextToken());
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length", Integer.toString(content.length));
            request.addHeader("Content-Type", protocolFactory.getContentType());
        } catch (Throwable t) {
            throw new SdkClientException("Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}

==> aws-java-sdk-gamelift-1.11.75-sources.jar: com/amazonaws/services/gamelift/model/transform/DescribePlayerSessionsRequestMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.gamelift.model.transform;

import java.io.ByteArrayInputStream;
import java.util.Collections;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.SdkClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.gamelift.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * DescribePlayerSessionsRequest Marshaller
 */
public class DescribePlayerSessionsRequestMarshaller implements Marshaller<Request<DescribePlayerSessionsRequest>, DescribePlayerSessionsRequest> {

    private final SdkJsonMarshallerFactory protocolFactory;

    public DescribePlayerSessionsRequestMarshaller(SdkJsonMarshallerFactory protocolFactory) {
        this.protocolFactory = protocolFactory;
    }

    public Request<DescribePlayerSessionsRequest> marshall(DescribePlayerSessionsRequest describePlayerSessionsRequest) {

        if (describePlayerSessionsRequest == null) {
            throw new SdkClientException("Invalid argument passed to marshall(...)");
        }

        Request<DescribePlayerSessionsRequest> request = new DefaultRequest<DescribePlayerSessionsRequest>(describePlayerSessionsRequest, "AmazonGameLift");
        request.addHeader("X-Amz-Target", "GameLift.DescribePlayerSessions");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final StructuredJsonGenerator jsonGenerator = protocolFactory.createGenerator();

            jsonGenerator.writeStartObject();

            if (describePlayerSessionsRequest.getGameSessionId() != null) {
                jsonGenerator.writeFieldName("GameSessionId").writeValue(describePlayerSessionsRequest.getGameSessionId());
            }
            if (describePlayerSessionsRequest.getPlayerId() != null) {
                jsonGenerator.writeFieldName("PlayerId").writeValue(describePlayerSessionsRequest.getPlayerId());
            }
            if (describePlayerSessionsRequest.getPlayerSessionId() != null) {
                jsonGenerator.writeFieldName("PlayerSessionId").writeValue(describePlayerSessionsRequest.getPlayerSessionId());
            }
            if (describePlayerSessionsRequest.getPlayerSessionStatusFilter() != null) {
                jsonGenerator.writeFieldName("PlayerSessionStatusFilter").writeValue(describePlayerSessionsRequest.getPlayerSessionStatusFilter());
            }
            if (describePlayerSessionsRequest.getLimit() != null) {
                jsonGenerator.writeFieldName("Limit").writeValue(describePlayerSessionsRequest.getLimit());
            }
            if (describePlayerSessionsRequest.getNextToken() != null) {
                jsonGenerator.writeFieldName("NextToken").writeValue(describePlayerSessionsRequest.getNextToken());
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length", Integer.toString(content.length));
            request.addHeader("Content-Type", protocolFactory.getContentType());
        } catch (Throwable t) {
            throw new SdkClientException("Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}
